==> tslib_1.9.orig.tar.xz: tslib-1.9/tests/ts_finddev.c <==
/*
 *  tslib/src/ts_finddev.c
 *
 *  Derived from tslib/src/ts_test.c by Douglas Lowder
 *
 * This file is placed under the GPL.  Please see the file
 * COPYING for more details.
 */
#include <stdio.h>
#include <stdlib.h>
#include <signal.h>
#include <sys/time.h>
#include <unistd.h>

#include "tslib.h"
#include "testutils.h"

static void usage(char **argv)
{
	printf("tslib " PACKAGE_VERSION "\n");
	printf("\n");
	printf("Usage: %s device_name wait_for_sec\n", argv[0]);
	printf("\tdevice_name  - tdevice to probe, example /dev/input/event0\n");
	printf("\twait_for_sec - wait seconds for touch event, if 0 - don't wait!\n");
	printf("\tReturn codes:\n");
	printf("\t  0          - timeout expired without receiving event.\n");
	printf("\t               But this maybe is TouchScreen.\n");
	printf("\t -1          - this is NOT TouchScreen device!\n");
	printf("\t  1          - this is TouchScreen for shure!\n");
	exit(-1);
}

static void alarm_handler(int sig)
{
	/* time is expired */
	printf("signal %d caught\n", sig);

	exit(0);
}

int main(int argc, char **argv)
{
	struct tsdev *ts;
	struct ts_sample samp;
	char *tsdevice = NULL;
	int waitsec;
	int ret;

	if (argc != 3)
		usage(argv);

	tsdevice = argv[1];
	waitsec = atoi(argv[2]);
	if (waitsec < 0)
		usage(argv);

	ts = ts_setup(tsdevice, 0);
	if (!ts)
		return -1;

	if (!waitsec)
		return 0;

	printf("Probe device %s, Please Touch Screen Anywhere in %i seconds! ...\n",
	       tsdevice, waitsec);
	signal(SIGALRM, alarm_handler);
	alarm(waitsec);
	ret = ts_read_raw(ts, &samp, 1);
	ts_close(ts);
	if (ret)
		return 1;

	return -1;
}

==> tslib_1.11.orig.tar.xz: tslib-1.11/tests/ts_finddev.c <==
/*
 *  tslib/src/ts_finddev.c
 *
 *  Derived from tslib/src/ts_test.c by Douglas Lowder
 *
 * This file is placed under the GPL.  Please see the file
 * COPYING for more details.
 */
#include <stdio.h>
#include <stdlib.h>
#include <signal.h>
#include <sys/time.h>
#include <unistd.h>

#include "tslib.h"

static void usage(char **argv)
{
	struct ts_lib_version_data *ver = ts_libversion();

	printf("tslib %s (library 0x%X)\n", ver->package_version, ver->version_num);
	printf("\n");
	printf("Usage: %s device_name wait_for_sec\n", argv[0]);
	printf("\tdevice_name  - tdevice to probe, example /dev/input/event0\n");
	printf("\twait_for_sec - wait seconds for touch event, if 0 - don't wait!\n");
	printf("\tReturn codes:\n");
	printf("\t  0          - timeout expired without receiving event.\n");
	printf("\t               But this maybe is TouchScreen.\n");
	printf("\t -1          - this is NOT TouchScreen device!\n");
	printf("\t  1          - this is TouchScreen for shure!\n");
	exit(-1);
}

static void alarm_handler(int sig)
{
	/* time is expired */
	printf("signal %d caught\n", sig);

	exit(0);
}

int main(int argc, char **argv)
{
	struct tsdev *ts;
	struct ts_sample samp;
	char *tsdevice = NULL;
	int waitsec;
	int ret;

	if (argc != 3)
		usage(argv);

	tsdevice = argv[1];
	waitsec = atoi(argv[2]);
	if (waitsec < 0)
		usage(argv);

	ts = ts_setup(tsdevice, 0);
	if (!ts)
		return -1;

	if (!waitsec)
		return 0;

	printf("Probe device %s, Please Touch Screen Anywhere in %i seconds! ...\n",
	       tsdevice, waitsec);
	signal(SIGALRM, alarm_handler);
	alarm(waitsec);
	ret = ts_read_raw(ts, &samp, 1);
	ts_close(ts);
	if (ret)
		return 1;

	return -1;
}
